package com.tzld.piaoquan.longarticle.service.local.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.tzld.piaoquan.longarticle.common.constants.TimeConstant;
import com.tzld.piaoquan.longarticle.common.enums.*;
import com.tzld.piaoquan.longarticle.dao.mapper.PlanAccountMapper;
import com.tzld.piaoquan.longarticle.dao.mapper.PublishContentMapper;
import com.tzld.piaoquan.longarticle.dao.mapper.PublishMiniprogramMapper;
import com.tzld.piaoquan.longarticle.model.bo.MatchContent;
import com.tzld.piaoquan.longarticle.model.bo.VideoDetail;
import com.tzld.piaoquan.longarticle.model.dto.MiniprogramCardRequest;
import com.tzld.piaoquan.longarticle.model.dto.PublishArticleData;
import com.tzld.piaoquan.longarticle.model.po.*;
import com.tzld.piaoquan.longarticle.model.vo.*;
import com.tzld.piaoquan.longarticle.service.local.AccountService;
import com.tzld.piaoquan.longarticle.service.local.CoreService;
import com.tzld.piaoquan.longarticle.service.local.PlanAccountService;
import com.tzld.piaoquan.longarticle.service.remote.AigcService;
import com.tzld.piaoquan.longarticle.service.remote.MatchService;
import com.tzld.piaoquan.longarticle.service.remote.VideoService;
import com.tzld.piaoquan.longarticle.service.remote.impl.SortServiceImpl;
import com.tzld.piaoquan.longarticle.utils.DateUtil;
import com.tzld.piaoquan.longarticle.utils.LarkRobotUtil;
import com.tzld.piaoquan.longarticle.utils.TimeZoneUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.time.LocalTime;
import java.util.*;
import java.util.concurrent.*;
import java.util.function.Function;
import java.util.stream.Collectors;

@Slf4j
@Service
public class CoreServiceImpl implements CoreService {

    @Autowired
    private AigcService aigcService;

    @Autowired
    private SortServiceImpl sortService;

    @Autowired
    private ContentServiceImpl contentService;

    @Autowired
    private MatchService matchService;

    @Autowired
    private VideoService videoService;

    @Autowired
    private CardServiceImpl cardService;

    @Autowired
    private PlanAccountMapper planAccountMapper;

    @Autowired
    private PlanAccountService planAccountService;

    @Autowired
    private PublishMiniprogramMapper publishMiniprogramMapper;

    @Autowired
    private PublishContentMapper publishContentMapper;

    @Autowired
    private PublicContentServiceImpl publicContentService;

    @Autowired
    private RootSourceServiceImpl rootSourceService;

    @Autowired
    private AccountService accountService;

    private static final Set<String> miniProgramWhiteList = new HashSet<String>() {{
        add("魔法美学馆");
        add("票圈大事件");
        add("生活情感叁读");
        add("生活慢时光");
        add("家家生活指南");
        add("妙招持家帮手");
        add("多彩妙生活");
        add("异闻趣事多");
        add("张阿姨爱美食");
        add("妙招技巧达人");
        add("充电宝宝");
        add("窦都事说");
        add("史记趣言");
        add("缘来养心厅");
        add("心灵情感驿站");
        add("票圈极速版");
        add("票圈乐活");
        add("票圈原创视频精选");
        add("票圈美文速递");
        add("生活良读");
        add("票圈热门");
        add("票圈奇闻");
        add("祝福养心厅");
        add("宝娃趣味游戏");
        add("音药金曲厅");
        add("奇文转发给老友");
        add("音药养心馆");
        add("小阳看天下");
        add("繁花史阁");
        add("观察家王小姐");
        add("退休无忧生活");
        add("农耕趣时刻");
        add("小惠爱厨房");
        add("趣史论");
        add("慧行社");
        add("姜子丫");
        add("婉央女子");
        add("六八评价");
        add("所见畅谈");
        add("老新说事");
        add("壹姐八卦");
        add("圈内侃八卦");
        add("奇闻有约");
        add("生活智慧正能量");
        add("爱姨生活妙招");
        add("日日有妙招");
        add("实在妙招");
        add("热血军中事");
        add("娱乐在前");
        add("八点说故事");
        add("俏生活秘籍");
        add("军莫愁");
        add("冀中轶事");
        add("该账号已注销");
        add("票圈正能量");
        add("票圈精彩");
        add("俏丽音乐相册");
        add("新品女装特价");
        add("票圈内容精选");
        add("票圈热议");
        add("每晚一个情感故事");
        add("职场鸢说");
        add("生活优选范");
        add("广场舞每天学");
        add("史趣探秘");
        add("史记有言");
        add("暖心一隅");
        add("麒阁史记");
        add("心海情澜起");
        add("那些历史");
        add("日常生活小技巧集");
        add("趣谈史记");
        add("日常巧思集");
        add("日常小妙招秘籍");
        add("晚年家人");
        add("老甄有话说");
        add("快乐生活妙技巧");
        add("持家有妙招");
        add("生活小优招");
        add("生活之大全");
        add("无忧生活情感");
        add("情感时光屋");
        add("幸福心灵指南");
        add("幸福生活有窍门");
        add("趣生活小妙招");
        add("理想晚年生活");
        add("青莲简史");
        add("闲时聊生活");
        add("史家霸唱");
        add("长年妙生活");
        add("理想老来生活");
        add("乡间牛人");
        add("妙晚年生活");
        add("百家之康阁");
        add("退休知音老友");
        add("奇趣妙招点子");
        add("无忧生活有点子");
        add("大嘴美食家");
        add("老来妙趣生活");
        add("妙农村生活");
        add("乡野风光");
        add("趣农村生活");
        add("谈趣史");
        add("持家妙招集");
        add("奇闻纪实");
        add("轻松生活方法");
        add("趣读奇事");
        add("晚年多享乐");
        add("福康俏生活");
        add("历史长河流淌");
        add("万事如意一家子");
        add("田耕闲话");
        add("趣读小史");
        add("精选生活管家");
        add("妙招多一点");
        add("食神日记");
        add("安享生活家");
        add("自在生活集");
        add("幸福俏生活");
        add("老来有知音");
        add("实用窍门君");
        add("幸福居家帮手");
        add("轻松俏生活");
        add("俏生活秒招姐");
        add("乐享生活有妙招");
        add("便捷生活妙招");
        add("天下达观");
        add("奇事时分秒");
        add("老来妙享生活");
        add("俏生活有窍门");
        add("金点子窍门");
        add("小方史论");
        add("无忧持家达人");
        add("博史鉴览");
        add("好招妙");
        add("福享暮年");
        add("奇读趣史");
        add("悠读生活");
        add("无羁之地");
        add("梦游的超级兵");
        add("票圈故事会");
        add("等读生活");
        add("生活是读");
        add("生活永读");
        add("生活修读");
        add("富读生活");
        add("每天趣生活");
        add("心读生活");
        add("生活超读");
        add("灵读生活");
        add("生活情感读");
        add("心绪情感碎语");
        add("慢品情感录");
        add("情感心绪语录");
        add("生活然读");
        add("生活复读");
        add("木雕集");
        add("早安探读");
        add("银发生活畅谈");
        add("好家乡好生活");
        add("退休精选汇集");
        add("趣闻生活妙招");
        add("大炮说大事");
        add("云响说大事");
        add("兵兵说大事");
        add("妙招趣帮手");
        add("优选持家派");
        add("快乐生活有方法");
        add("趣览史说");
        add("史说新看");
        add("田耕享生活");
        add("博阅历史");
        add("农家田耕季");
        add("趣享谈晚年");
        add("情感美文一刻");
        add("夕阳缘分");
        add("慧观万象");
        add("溪谷悠享");
        add("奇事探索");
        add("山林探趣");
        add("生活达人妙招库");
        add("妙招知识宝典");
        add("秋月景如诗");
        add("田耕乡悦");
        add("心素静和秋");
        add("喜气洋洋一家亲");
        add("福星高照一家人");
        add("等风画铠雪");
        add("幸福的一大家");
        add("实用妙招屋");
        add("食光佳肴");
        add("老来俏生活");
        add("善语生活");
        add("妙招百科全知");
        add("生活之有道");
        add("家庭生活技巧笔记");
        add("爱家常经典技巧");
        add("家有妙招好生活");
        add("生活妙招技巧集");
        add("生活则读");
        add("永远快乐一家人");
        add("玉玉有妙招");
        add("似朦菲朦");
        add("快乐交流一家人");
        add("读史趣谈");
        add("持家优选金点子");
        add("生活持家派");
        add("持家有方法");
        add("文史新看");
        add("妙读奇闻");
        add("暮年享乐");
        add("趣谈暮年");
        add("乡土趣享");
        add("畅享福晚年");
        add("持家妙选派");
        add("探秘趣闻");
        add("小桥说大事");
        add("雨盈说大事");
        add("精粹国学论");
        add("生活巧事通");
        add("巧手生活全录");
        add("解忧情感集");
        add("经典情感悦读");
        add("飞屋情感故事");
        add("妙招百事屋");
        add("生活指南伴读");
        add("趣味生活漫时光");
        add("彩读生活");
        add("果读生活");
        add("生活翔读");
        add("奇事论读");
        add("史册趣读");
        add("奇趣百态说");
        add("心雨情感说");
        add("春日畅谈");
        add("味读生活");
        add("生活往读");
        add("喜乐生活指南");
        add("生活话读");
        add("生活介读");
        add("生活凡读");
        add("生活释读");
        add("生活世读");
        add("爱家用妙招实用");
        add("爱家实用妙招");
        add("老年智慧小技巧");
        add("暖春畅谈");
        add("日常实用生活宝典");
        add("生活集读");
        add("茶乡小生活");
        add("知己生活妙招");
        add("生活闻读");
        add("晚年健读");
        add("晚年品读");
        add("技巧生活艺术家");
        add("生活妙招贴士指南");
        add("生活巧招秘籍馆");
        add("居家妙招小常识");
        add("无忧持家妙招");
        add("精选生活日常百科");
        add("实用技巧省时助手");
        add("日常技巧指南");
        add("日常生活妙招指南");
        add("持家神妙招");
        add("汉史趣看");
        add("精致持家派");
        add("农耕一刻");
        add("寒山见读");
        add("轻松妙生活");
        add("趣看史记");
        add("趣史说");
        add("田耕一刻");
        add("兰若浅谈");
        add("慢读佳文");
        add("生活乐窍门");
        add("生活精选趣招");
        add("居家欢乐味");
        add("爱家常妙招实用");
        add("伴你相随");
        add("生活先锋事");
        add("生活健读");
        add("生活近读");
        add("漫读生活");
        add("生活颂读");
        add("生活展读");
        add("家用妙趣");
        add("情深花悦");
        add("趣味生活漫谈");
        add("生活问读");
        add("生活陆读");
        add("生活白读");
        add("生活跟读");
        add("生活及读");
        add("晚年福悦堂");
        add("乡野乐时光");
        add("趣味生活方式");
        add("山月清读");
        add("浅吟倾心听");
        add("暮雨小巷");
        add("梦回旧时光");
        add("冬日畅谈");
        add("退休生活百事通");
        add("生活二读");
        add("妙招百事晓");
        add("农耕田野生活");
        add("生活五读");
        add("666个生活小妙招");
        add("幸福晚年录");
        add("幸福的趣生活");
        add("幸福无忧小窍门");
        add("幸福地带养身心");
        add("黄粱说大事");
        add("国学大事说");
        add("老来福之说");
        add("喜乐晚年");
        add("生活趣窍门");
        add("退休三缺一");
        add("快乐生活新方向");
        add("灵波悦文");
        add("贝俊逸文");
        add("田地杂谈");
        add("欢乐老来伴");
        add("彤浩初说");
        add("观文史说");
        add("云景史记");
        add("奇看趣闻");
        add("乡野地带");
        add("趣闻汉史");
        add("史君记");
        add("持家有窍门");
        add("四季田野");
        add("趣生活技巧");
        add("无忧居家达人");
        add("俏持家达人");
        add("博览史论");
        add("欢聚暮年");
        add("妙晚年日记");
        add("俏生活小妙招");
        add("轻松妙生活家");
        add("香茗史论");
        add("享暮年华乐");
        add("趣论史说");
        add("情感快乐说");
        add("美好意义时光");
        add("喜乐生活宝典");
        add("俏生活小锦囊");
        add("小包教生活");
        add("文史茶馆");
        add("生活长读");
        add("玉淑说大事");
        add("老来说大事");
        add("卓越视角");
        add("家和乡间趣");
        add("小妙招悦享");
        add("幽谷逸闻");
        add("谷涧趣行");
        add("赞读生活");
        add("缘分情感说");
        add("晚年妙读");
        add("妙读生活");
        add("生活常识区");
        add("生活大小常识");
        add("舒誉轶文");
        add("鸿云念文");
        add("都市佳人伴渎");
        add("郸英光语");
        add("清怡素语");
        add("岑山旭读");
        add("杰云若语");
        add("妙生活君");
        add("都市退休蕊渎");
        add("都市佳人沁读");
        add("一品趣闻");
        add("都市佳人蕊读");
        add("趣史说说");
        add("汉史遍览");
        add("趣史汇看");
        add("田地杂论");
        add("趣享晚年");
        add("少凌雪文");
        add("趣史新看");
        add("农耕笔记");
        add("趣闻时分秒");
        add("持家妙招宝库");
        add("谈老来生活");
        add("田耕生活");
        add("精选俏生活");
        add("家有窍门大全");
        add("窍门天天见");
        add("理想俏生活");
        add("民族风歌曲汇");
        add("好歌不停放");
        add("好学广场舞");
        add("趣谈小镇");
        add("生活教读");
        add("生活与技巧");
        add("读些国学智慧");
        add("看迹旅途");
        add("丰富岁月");
        add("智慧岁月人生");
        add("精选妙生活");
        add("肥仔美食课");
        add("新独旅记");
        add("生活知讯室");
        add("生活醒读");
        add("生活蜜读");
        add("历史客栈2020");
        add("退休读书社");
        add("唯心箴言");
        add("倾心好文伴你");
        add("妙生活有一招");
        add("正能量文学");
        add("家家妙招指南");
        add("幸福晚年有一招");
        add("家庭点子妙招");
        add("生活妙册站");
        add("文不论史");
        add("清晨听雨聲");
        add("淡雅青然");
        add("花开知椿");
        add("趣闻史汇");
        add("寻逸秀谈");
        add("甄选佳文");
        add("趣史站台");
        add("精彩妙招知");
        add("福康享生活");
        add("楠风青云");
        add("好文不停送");
        add("铭人榜样");
        add("秋来枫自红");
        add("闲情故语");
        add("杂史微鉴");
        add("居家新趣文");
        add("旅途感读");
        add("俏生活妙招汇");
        add("退休幸福晚年生活");
        add("趣文热看");
    }};

    public void initAccountSpecialSettings() {
        List<SpecialSettingVO> specialSettings = aigcService.getSpecialSetting();
        if (CollectionUtils.isEmpty(specialSettings)) {
            return;
        }
        for (SpecialSettingVO specialSettingVO : specialSettings) {
            if (CollectionUtils.isEmpty(specialSettingVO.getAccountList())) {
                continue;
            }
            for (SpecialSettingAccountVO specialSettingAccountVO : specialSettingVO.getAccountList()) {
                AccountSpecialSettings accountSpecialSettings = new AccountSpecialSettings();
                accountSpecialSettings.setSpecialSettingId(specialSettingVO.getId());
                accountSpecialSettings.setEffectiveDate(specialSettingVO.getEffectiveDate());
                accountSpecialSettings.setAccountId(specialSettingAccountVO.getId());
                accountSpecialSettings.setPublishPushTime(specialSettingVO.getPushTime());
                accountSpecialSettings.setPushType(specialSettingVO.getPushType());
                accountSpecialSettings.setPublishNum(specialSettingVO.getPushNum());
                if (!CollectionUtils.isEmpty(specialSettingVO.getExcludeArticleIndexList())) {
                    List<Integer> collect = specialSettingVO.getExcludeArticleIndexList().stream()
                            .map(Integer::parseInt).collect(Collectors.toList());
                    accountSpecialSettings.setExcludeContentIndex(JSON.toJSONString(collect));
                }
                accountService.saveOrUpdateAccountSpecialSettings(accountSpecialSettings);
            }
        }

    }

    @Override
    public void initPlanAccount() {
        //例外设置查询和存储
        Map<String, AccountSpecialSettings> accountSpecialSettingsMap = null;
        Map<String, List<PlanAccount>> planAccountMap = new HashMap<>();
        List<AccountSpecialSettings> accountSpecialSettings = accountService.getAccountSpecialSettings();
        if (!CollectionUtils.isEmpty(accountSpecialSettings)) {
            accountSpecialSettingsMap = accountSpecialSettings.stream()
                    .collect(Collectors.toMap(AccountSpecialSettings::getAccountId, Function.identity()));
        }
        //操作计划遍历
        List<Plan> planList = planAccountService.getPlanList();
        Set<String> planIdSet = planList.stream().map(Plan::getPlanId).collect(Collectors.toSet());
        List<LongArticleSystemPlan> allLongArticleSystemPlans = aigcService.getAllLongArticleSystemPlan();
        for (LongArticleSystemPlan longArticleSystemPlan : allLongArticleSystemPlans) {
            Plan plan = createPlan(longArticleSystemPlan);
            planAccountService.saveOrUpdatePlan(plan);
            planIdSet.remove(longArticleSystemPlan.getId());
            //获取排序策略
            Map<String, String> sortStgMap = new HashMap<>();
            List<GzhArticleSortTaskParam> gzhArticleSortTask = longArticleSystemPlan.getGzhArticleSortTask();
            for (GzhArticleSortTaskParam gzhArticleSortTaskParam : gzhArticleSortTask) {
                String strategy = gzhArticleSortTaskParam.getStrategy();
                List<String> accountIds = gzhArticleSortTaskParam.getAccountIds();
                for (String accountId : accountIds) {
                    sortStgMap.put(accountId, strategy);
                }
            }
            //获取小程序策略
            Map<String, MiniprogramInsertTaskParam> miniStgMap = new HashMap<>();
            List<MiniprogramInsertTaskParam> miniprogramInsertTasks = longArticleSystemPlan.getMiniprogramInsertTasks();
            for (MiniprogramInsertTaskParam miniprogramInsertTaskParam : miniprogramInsertTasks) {
                List<String> accountIds = miniprogramInsertTaskParam.getAccountIds();
                for (String accountId : accountIds) {
                    miniStgMap.put(accountId, miniprogramInsertTaskParam);
                }
            }
            List<PlanAccount> planAccounts = planAccountService.getPlanAccountByPlanId(longArticleSystemPlan.getId());
            Set<String> accountIdSet = planAccounts.stream().map(PlanAccount::getAccountId).collect(Collectors.toSet());
            for (LongArticleSystemPlanAccount account : longArticleSystemPlan.getAccountList()) {
                PlanAccount planAccount = new PlanAccount();
                String accountId = account.getId();
                accountIdSet.remove(accountId);
                planAccount.setPlanId(longArticleSystemPlan.getId());
                planAccount.setPlanName(longArticleSystemPlan.getName());
                planAccount.setAccountId(accountId);
                planAccount.setAccountName(account.getName());
                planAccount.setGhId(account.getGhId());
                planAccount.setPublishOpenFlag(account.getPublishOpenFlag());
                planAccount.setPublishRate(longArticleSystemPlan.getPublishRate());
                planAccount.setPublishDate(longArticleSystemPlan.getPublishDate());
                planAccount.setPublishNum(longArticleSystemPlan.getPublishNum());
                planAccount.setPublishWindowStart(longArticleSystemPlan.getPublishWindowStart());
                planAccount.setPublishWindowEnd(longArticleSystemPlan.getPublishWindowEnd());
                planAccount.setPublishTimeInterval(longArticleSystemPlan.getPublishTimeInterval());
                planAccount.setPublishNum(longArticleSystemPlan.getPublishNum());
                planAccount.setPublishPreNum(longArticleSystemPlan.getPublishPerNum());
                planAccount.setPublishPreMinNum(longArticleSystemPlan.getPublishPerMinNum());
                planAccount.setPublishPushTime(longArticleSystemPlan.getPublishPushTime());
                planAccount.setPushType(longArticleSystemPlan.getPushType());
                planAccount.setMiniprogramInsertFlag(longArticleSystemPlan.getMiniprogramInsertFlag());
                MiniprogramInsertTaskParam miniprogramInsertTaskParam = miniStgMap.get(accountId);
                if (miniprogramInsertTaskParam != null) {
                    planAccount.setMiniprogramUseType(miniprogramInsertTaskParam.getMiniprogramUseType());
                    planAccount.setMiniStrategy(miniprogramInsertTaskParam.getStrategy());
                }
                if (sortStgMap.containsKey(accountId)) {
                    planAccount.setSortStrategy(sortStgMap.get(accountId));
                }
                planAccount.setPushType(longArticleSystemPlan.getPushType());
                if (accountSpecialSettingsMap != null && accountSpecialSettingsMap.containsKey(planAccount.getAccountId())) {
                    planAccountMap.computeIfAbsent(planAccount.getAccountId(), k -> new ArrayList<>()).add(planAccount);
                } else {
                    planAccountService.saveOrUpdatePlanAccount(planAccount);
                }
            }
            if (CollectionUtils.isEmpty(accountIdSet)) {
                continue;
            }
            for (String accountId : accountIdSet) {
                planAccountService.delAccount(longArticleSystemPlan.getId(), accountId);
            }

        }
        if (CollectionUtils.isEmpty(planIdSet)) {
            return;
        }
        for (String planId : planIdSet) {
            planAccountService.delPlan(planId);
        }

        //例外设置处理
        if (!CollectionUtils.isEmpty(planAccountMap)) {
            setSpecialAccount(planAccountMap, accountSpecialSettingsMap);
        }
    }

    private void setSpecialAccount(Map<String, List<PlanAccount>> planAccountMap,
                                   Map<String, AccountSpecialSettings> accountSpecialSettingsMap) {
        for (Map.Entry<String, List<PlanAccount>> entry : planAccountMap.entrySet()) {
            String accountId = entry.getKey();
            List<PlanAccount> planAccounts = entry.getValue();
            AccountSpecialSettings accountSpecialSettings = accountSpecialSettingsMap.get(accountId);
            if (accountSpecialSettings == null) {
                LarkRobotUtil.sendMessage("获取例外设置失败，accountId=" + accountId);
                continue;
            }
            //根据例外设置账号判断，当天已经有发送成功的记录，确保不会生成新的例外操作计划
            boolean isSend = false;
            List<PlanAccount> planAccountList = planAccountService.getPlanAccount(accountId);
            for (PlanAccount planAccount : planAccountList) {
                int sendCount = publicContentService.getSendCount(planAccount.getId());
                if (sendCount > 0) {
                    isSend = true;
                    break;
                }
            }
            if (isSend) {
                continue;
            }

            //例外设置的新增和更新
            List<PlanAccount> normalPlanAccounts = planAccountList.stream().filter(e -> e.getIsDelete() == 0).filter(e -> e.getPublishOpenFlag() == 1).collect(Collectors.toList());
            if (CollectionUtils.isEmpty(normalPlanAccounts)) {
                Optional<PlanAccount> firstAccount = planAccounts.stream().min((a1, a2) -> -a1.getPublishNum().compareTo(a2.getPublishNum()));
                if (!firstAccount.isPresent()) {
                    continue;
                }
                PlanAccount targetPlanAccount = firstAccount.get();
                for (PlanAccount planAccount : planAccounts) {
                    if (!Objects.equals(planAccount.getPlanId(), targetPlanAccount.getPlanId())) {
                        planAccount.setPublishOpenFlag(0);
                        planAccountService.saveOrUpdatePlanAccount(planAccount);
                        continue;
                    }
                    updateAccountSetting(accountSpecialSettings, planAccount);
                    planAccountService.saveOrUpdatePlanAccount(planAccount);
                }
            } else {
                if (normalPlanAccounts.size() == 1) {
                    PlanAccount planAccount = normalPlanAccounts.get(0);
                    updateAccountSetting(accountSpecialSettings, planAccount);
                    planAccountService.saveOrUpdatePlanAccount(planAccount);
                } else {
                    LarkRobotUtil.sendMessage("存在多个例外计划，accountId=" + accountId);
                    for (PlanAccount planAccount : planAccounts) {
                        planAccount.setPublishOpenFlag(0);
                        planAccountService.saveOrUpdatePlanAccount(planAccount);
                    }
                }
            }
        }
    }

    private void updateAccountSetting(AccountSpecialSettings accountSpecialSettings, PlanAccount planAccount) {
        planAccount.setPushType(accountSpecialSettings.getPushType());
        if (PublishGzhPushTypeEnum.manual_push.getVal().equals(accountSpecialSettings.getPushType())) {
            planAccount.setPublishWindowStart(accountSpecialSettings.getPublishPushTime());
            //保证手动推送的结束时间在推送开始时间之后
            planAccount.setPublishWindowEnd("23:00:00");
        } else {
            planAccount.setPublishPushTime(accountSpecialSettings.getPublishPushTime());
        }
        planAccount.setPublishPreNum(accountSpecialSettings.getPublishNum());
        planAccount.setPublishNum(accountSpecialSettings.getPublishNum());
        int size = 0;
        if (StringUtils.isNotEmpty(accountSpecialSettings.getExcludeContentIndex())) {
            size = JSONArray.parseArray(accountSpecialSettings.getExcludeContentIndex(), Integer.class).size();
        }
        if (planAccount.getPublishPreMinNum() > accountSpecialSettings.getPublishNum() - size) {
            planAccount.setPublishPreMinNum(accountSpecialSettings.getPublishNum() - size);
        }
        planAccount.setExcludeContentIndex(accountSpecialSettings.getExcludeContentIndex());
    }


    private Plan createPlan(LongArticleSystemPlan longArticleSystemPlan) {
        Plan plan = new Plan();
        plan.setPlanId(longArticleSystemPlan.getId());
        plan.setPlanName(longArticleSystemPlan.getName());
        plan.setPublishRate(longArticleSystemPlan.getPublishRate());
        plan.setPublishDate(longArticleSystemPlan.getPublishDate());
        plan.setPublishWindowStart(longArticleSystemPlan.getPublishWindowStart());
        plan.setPublishWindowEnd(longArticleSystemPlan.getPublishWindowEnd());
        plan.setPublishTimeInterval(longArticleSystemPlan.getPublishTimeInterval());
        plan.setPublishNum(longArticleSystemPlan.getPublishNum());
        plan.setPublishPreNum(longArticleSystemPlan.getPublishPerNum());
        plan.setPublishPreMinNum(longArticleSystemPlan.getPublishPerMinNum());
        plan.setPublishPushTime(longArticleSystemPlan.getPublishPushTime());
        plan.setPushType(longArticleSystemPlan.getPushType());
        plan.setMiniprogramInsertFlag(longArticleSystemPlan.getMiniprogramInsertFlag());
        return plan;
    }


    // 定义一个阻塞队列
    private static final ArrayBlockingQueue<MatchContent> matchQueue = new ArrayBlockingQueue<>(100000);

    private static final ArrayBlockingQueue<PlanAccount> coreQueue = new ArrayBlockingQueue<>(100000);


    private static final int size = 5;
    // 定义一个线程池，设置消费线程的数量
    private static final ThreadPoolExecutor matchPoolExecutor = (ThreadPoolExecutor) Executors.newFixedThreadPool(size);

    private static final ThreadPoolExecutor corePoolExecutor = (ThreadPoolExecutor) Executors.newFixedThreadPool(5);


    @Override
    public void matchContent() throws InterruptedException {
        if (matchPoolExecutor.getCorePoolSize() - matchPoolExecutor.getActiveCount() > 0) {
            int threadSize = matchPoolExecutor.getCorePoolSize() - matchPoolExecutor.getActiveCount();
            log.info("threadNum={}", threadSize);
            CountDownLatch countDownLatch = new CountDownLatch(threadSize);
            // 启动消费者线程
            for (int i = 0; i < threadSize; i++) {
                matchPoolExecutor.submit(new Thread(() -> {
                    log.info("启动匹配小程序线程");
                    while (true) {
                        try {
                            // 超过 5 分钟没有数据，销毁当前线程
                            MatchContent matchContent = matchQueue.poll(5, TimeUnit.MINUTES); // 等待最多 5 分钟
                            if (matchContent == null) {
                                break; // 退出当前线程
                            }
                            //只匹配小程序文章不做处理
                            if (Objects.equals(matchContent.getSourceType(), SourceTypesEnum.longArticleVideoPoolSource.getVal())) {
                                MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                                statusParam.setStatus(MatchResultStatusEnum.SUCCESS.getStatusCode());
                                statusParam.setPublishContentId(matchContent.getPublishContentId());
                                aigcService.updateMatchMiniprogramStatus(statusParam);
                                continue;
                            }
                            MatchVideo matchVideo = contentService.getContent(matchContent.getSourceId(), matchContent.getGhId(), 2);
                            if (matchVideo != null) {
                                Integer contentStatus = matchVideo.getContentStatus();
                                if (ContentStatusEnum.isSuccess(contentStatus)) {
                                    MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                                    statusParam.setStatus(MatchResultStatusEnum.SUCCESS.getStatusCode());
                                    statusParam.setPublishContentId(matchContent.getPublishContentId());
                                    aigcService.updateMatchMiniprogramStatus(statusParam);
                                    contentService.addMatchContent(matchVideo, matchContent.getPublishContentId());
                                    continue;
                                }
                                if (ContentStatusEnum.isFail(contentStatus)) {
                                    MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                                    statusParam.setStatus(MatchResultStatusEnum.FAIL.getStatusCode());
                                    statusParam.setPublishContentId(matchContent.getPublishContentId());
                                    String errorMessage = ContentStatusEnum.getErrorMessage(contentStatus);
                                    statusParam.setErrorMsg(errorMessage);
                                    aigcService.updateMatchMiniprogramStatus(statusParam);
                                    contentService.addMatchContent(matchVideo, matchContent.getPublishContentId());
                                }
                            } else {
                                MiniprogramCardRequest request = new MiniprogramCardRequest();
                                request.setGhId(matchContent.getGhId());
                                request.setAccountName(matchContent.getAccountName());
                                request.setContent(matchContent.getContent());
                                request.setTitle(matchContent.getTitle());
                                //请求到新服务
                                request.setStrategy("strategy_v2");
                                request.setArticleId(matchContent.getSourceId());
                                request.setFlowPoolLevelTag(matchContent.getFlowPoolLevelTag());
                                request.setPublishFlag(2);
                                Integer status = matchService.matchMiniprogramVideo(request);
                                if (status == MatchRequestStatusEnum.NOT_CONTENT.getStatusCode()) {
                                    MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                                    statusParam.setStatus(MatchResultStatusEnum.FAIL.getStatusCode());
                                    statusParam.setPublishContentId(matchContent.getPublishContentId());
                                    String errorMessage = "没有文章内容";
                                    statusParam.setErrorMsg(errorMessage);
                                    aigcService.updateMatchMiniprogramStatus(statusParam);
                                }
                            }
                        } catch (InterruptedException e) {
                            throw new RuntimeException(e);
                        }
                    }
                    log.info("启动匹配小程序线程结束");
                    countDownLatch.countDown();
                }));
            }

            List<PlanAccount> matchPlanAccounts = planAccountService.getMatchPlanAccount();
            if (CollectionUtils.isEmpty(matchPlanAccounts)) {
                return;
            }
            for (PlanAccount planAccount : matchPlanAccounts) {
                GetContentsParam param = new GetContentsParam();
                param.setAccountId(planAccount.getAccountId());
                param.setPlanId(planAccount.getPlanId());
                LongArticleSystemContentVO longArticleSystemContentVO = aigcService.getContentItemList(param);
                if (longArticleSystemContentVO == null || CollectionUtils.isEmpty(longArticleSystemContentVO.getContentItemList())) {
                    continue;
                }
                log.info("longArticleSystemContentVO totalCount={}", longArticleSystemContentVO.getTotalCount());
                for (ContentItemVO contentItemVO : longArticleSystemContentVO.getContentItemList()) {
                    MatchContent matchContent = new MatchContent();
                    matchContent.setSourceId(contentItemVO.getSourceId());
                    matchContent.setGhId(planAccount.getGhId());
                    matchContent.setPublishContentId(contentItemVO.getPublishContentId());
                    matchContent.setAccountName(planAccount.getAccountName());
                    matchContent.setContent(contentItemVO.getContent());
                    matchContent.setTitle(contentItemVO.getTitle());
                    matchContent.setFlowPoolLevelTag(contentItemVO.getFlowPoolLevelTag());
                    matchContent.setSourceType(contentItemVO.getSourceType());
                    matchContent.setChannelContentId(contentItemVO.getChannelContentId());
                    try {
                        matchQueue.put(matchContent);
                    } catch (InterruptedException e) {
                        throw new RuntimeException(e);
                    }
                }
            }
            countDownLatch.await();
        }
    }


    private boolean effectiveTime(String startWindow, String endWindow, TimeZoneUtil.Timezone timezone) {
        if (!org.springframework.util.StringUtils.hasText(startWindow) || !org.springframework.util.StringUtils.hasText(endWindow)) {
            return true;
        }
        LocalTime currentTime = TimeZoneUtil
                .currentTime(Optional.ofNullable(timezone).orElse(TimeZoneUtil.Timezone.china));
        return currentTime.isAfter(LocalTime.parse(startWindow)) && currentTime.isBefore(LocalTime.parse(endWindow));
    }

    public boolean checkPlanAccount(PlanAccount planAccount) {
        boolean isGzhGroupPushPlan = Objects.nonNull(planAccount.getPushType())
                && PublishGzhPushTypeEnum.auto_group_publish.getVal().equals(planAccount.getPushType());
        boolean flag = true;
        // 固定日期
        if (planAccount.getPublishRate() == 1) {
            List<Integer> weeks = JSON.parseArray(planAccount.getPublishDate(), Integer.class);
            if (!weeks.contains(TimeZoneUtil.getTodayDayOfWeek(TimeZoneUtil.Timezone.china))) {
                planAccount.setStatus(2);
                planAccountMapper.updateByPrimaryKeySelective(planAccount);
                return false;
            }
        }
        // 指定时间
        if (isGzhGroupPushPlan && StringUtils.isNotEmpty(planAccount.getPublishPushTime())) {
            long pushTime = DateUtil.convertToTimestamp(planAccount.getPublishPushTime());
            long nowTime = new Date().getTime();
            // 当前时间距离目标时间超过30分钟
            if (nowTime + 30 * TimeConstant.MILLISECOND_MINUTE < pushTime) {
                return false;
            }
            // 当前时间已经超过目标时间600分钟
            if (nowTime - 600 * TimeConstant.MILLISECOND_MINUTE > pushTime) {
                return false;
            }
        } else if (StringUtils.isNotEmpty(planAccount.getPublishWindowStart())
                && StringUtils.isNotEmpty(planAccount.getPublishWindowEnd())) {
            if (!effectiveTime(planAccount.getPublishWindowStart(), planAccount.getPublishWindowEnd(),
                    TimeZoneUtil.Timezone.china)) {
                return false;
            }
            if (planAccount.getPublishTimeInterval() != null) {
                // 找到该账号最近发布的内容，判断时间间隔
                PublishContentExample example = new PublishContentExample();
                example.createCriteria().andStatusIn(Arrays.asList(1, 2))
                        .andCreateTimeGreaterThan(DateUtil.getThatDayDate())
                        .andPlanAccountIdEqualTo(planAccount.getId());
                example.setOrderByClause("create_time desc");
                List<PublishContent> publishContents = publishContentMapper.selectByExample(example);
                if (!CollectionUtils.isEmpty(publishContents)) {
                    long time = System.currentTimeMillis() - publishContents.get(0).getCreateTime().getTime();
                    if (time < planAccount.getPublishTimeInterval() * 60 * 1000L) {
                        return false;
                    }
                }
            }
        }
        PushRecordParam param = new PushRecordParam();
        param.setPlanId(planAccount.getPlanId());
        param.setPublishAccountId(planAccount.getAccountId());
        List<PushRecordVO> todayPushRecords = aigcService.getTodayPushRecords(param);


        //查询aigc发布成功数量
        int aigcCount = 0;
        if (!CollectionUtils.isEmpty(todayPushRecords)) {
            List<PushRecordVO> collect = todayPushRecords.stream()
                    .filter(e -> ((e.getPushStatus() != 3) && (e.getPublishStatus() != 3))).collect(Collectors.toList());
            if (!CollectionUtils.isEmpty(collect)) {
                for (PushRecordVO pushRecordVO : collect) {
                    if (pushRecordVO.getPublishContentCount() != null) {
                        aigcCount += pushRecordVO.getPublishContentCount();
                    }
                }
            }
        }
        //长文系统发布数量
        int sendCount = publicContentService.getSendCount(planAccount.getId());
        //取发布数量多的
        sendCount = Math.max(aigcCount, sendCount);
        if (isGzhGroupPushPlan) {
            //公众号群发每天只能成功发布一次
            if (sendCount >= 1) {
                return false;
            }
            //公众号群发每天最多尝试3次
            if (planAccount.getRetryCount() >= 3) {
                planAccount.setStatus(3);
                planAccountMapper.updateByPrimaryKeySelective(planAccount);
                LarkRobotUtil.sendMessage("计划发布失败3次，请查看 账号计划id为" + planAccount.getPlanId());
                return false;
            }
        }
        Integer publishNum = planAccount.getPublishNum();
        int size = 0;
        if (StringUtils.isNotEmpty(planAccount.getExcludeContentIndex())) {
            size = JSONArray.parseArray(planAccount.getExcludeContentIndex(), Integer.class).size();
        }
        if (publishNum == null || publishNum == 0) {
            LarkRobotUtil.sendMessage("发布数量设置为0 planAccountId=" + planAccount.getId());
            return false;
        }
        if (sendCount >= publishNum - size) {
            return false;
        }

        int todayNeedSendCount = publishNum - sendCount;
        // 本次推送数量
        Integer prePushNum = planAccount.getPublishPreNum();
        if (Objects.isNull(prePushNum)) {
            prePushNum = 1;
        }
        //如果预计推送数量大于剩余推送数量  本次数量设置为剩余推送数量
        if (prePushNum > todayNeedSendCount) {
            prePushNum = todayNeedSendCount;
        }
        // 自动发布消息，每次暂时限定发布一条
        if (PublishGzhPushTypeEnum.robopost.getVal().equals(planAccount.getPushType())) {
            prePushNum = 1;
        }
        // 本次最少推送数量
        Integer preMinPushNum = planAccount.getPublishPreMinNum();
        if (Objects.isNull(preMinPushNum)) {
            preMinPushNum = prePushNum;
        }
        if (preMinPushNum > prePushNum) {
            preMinPushNum = prePushNum;
        }
        planAccount.setPublishPreNum(prePushNum);
        planAccount.setPublishPreMinNum(preMinPushNum);
        return flag;
    }


    @Override
    public void core() throws InterruptedException {
        if (corePoolExecutor.getCorePoolSize() - corePoolExecutor.getActiveCount() > 0) {
            int threadSize = corePoolExecutor.getCorePoolSize() - corePoolExecutor.getActiveCount();
            log.info("threadNum={}", threadSize);
            CountDownLatch countDownLatch = new CountDownLatch(threadSize);
            // 启动消费者线程
            for (int i = 0; i < threadSize; i++) {
                corePoolExecutor.submit(new Thread(() -> {
                    log.info("启动核心操作线程");
                    while (true) {
                        try {
                            // 超过 5 分钟没有数据，销毁当前线程
                            PlanAccount planAccount = coreQueue.poll(5, TimeUnit.MINUTES); // 等待最多 5 分钟
                            if (planAccount == null) {
                                break; // 退出当前线程
                            }
                            operatePlanAccount(planAccount);
                        } catch (Exception e) {
                            log.error("", e);
                        }
                    }
                    log.info("核心操作线程结束");
                    countDownLatch.countDown();
                }));
            }
            List<PlanAccount> planAccounts;
            planAccounts = planAccountService.getNormalPlanAccount();
            if (CollectionUtils.isEmpty(planAccounts)) {
                return;
            }
            for (PlanAccount planAccount : planAccounts) {
                coreQueue.put(planAccount);
            }
            countDownLatch.await();
        }
    }

    public void operatePlanAccount(PlanAccount planAccount) {
        boolean flag = checkPlanAccount(planAccount);
        log.info("planAccount={}, flag={}", planAccount, flag);
        if (!flag) {
            return;
        }
        //获取待排序数据  数量不足会返回空list
        List<PublishArticleData> rankList = contentService.getWaitingSort(planAccount);
        if (CollectionUtils.isEmpty(rankList)) {
            return;
        }
        if (StringUtils.isNotEmpty(planAccount.getSortStrategy())) {
            rankList = contentService.getSortList(planAccount);
            if (CollectionUtils.isEmpty(rankList)) {
                return;
            }
        }
        //文章处理  小程序查询和发布
        List<PushContentParam> pushContentList = new ArrayList<>();
        List<Long> sendIds = new ArrayList<>();
        for (PublishArticleData publishArticleData : rankList) {
            PushContentParam contentParam = new PushContentParam();
            PublishContent publishContent = publicContentService.getPublishContent(planAccount, publishArticleData);
            if (publishContent == null) {
                continue;
            }
            //临时逻辑 白名单内发小程序
            boolean isWhiteAccount = miniProgramWhiteList.contains(planAccount.getAccountName());
            //判断是否插入小程序
            if (isWhiteAccount && planAccount.getMiniprogramInsertFlag() != null && planAccount.getMiniprogramInsertFlag() == 1) {
                //获取小程序
                List<PublishMiniprogram> publishMiniprogramList = publicContentService.getPublishMiniprograms(publishContent);
                //不存在则重新生成
                if (CollectionUtils.isEmpty(publishMiniprogramList)) {
                    if (Objects.equals(publishContent.getSourceType(), SourceTypesEnum.longArticleVideoPoolSource.getVal())) {
                        List<VideoDetail> videoDetails = contentService.getOnlyMiniPublishVideoDetail(publishContent);
                        log.info("publishContentId={}, videoDetails={}", publishContent.getId(), videoDetails);
                        if (CollectionUtils.isEmpty(videoDetails)) {
                            continue;
                        }
                        publishMiniprogramList = getPublishMiniprogramList(videoDetails, planAccount, publishContent);
                        if (CollectionUtils.isEmpty(publishMiniprogramList)) {
                            continue;
                        }
                    } else {
                        MatchVideo matchVideo = contentService.getMatchVideo(publishContent, planAccount);
                        if (matchVideo == null) {
                            continue;
                        }
                        List<VideoDetail> videoDetails = contentService.getPublishVideoDetail(publishContent, planAccount, matchVideo);
                        log.info("publishContentId={}, videoDetails={}", publishContent.getId(), videoDetails);
                        if (CollectionUtils.isEmpty(videoDetails)) {
                            continue;
                        }
                        publishMiniprogramList = getPublishMiniprogramList(videoDetails, planAccount, publishContent);
                        if (CollectionUtils.isEmpty(publishMiniprogramList)) {
                            continue;
                        }
                        contentService.updateMatchContent(publishContent, publishMiniprogramList, matchVideo);
                    }
                }
                log.info("publishMiniprogramList={}", publishMiniprogramList);
                List<PublishMiniprogramParam> publishCardList = getPublishCardList(publishMiniprogramList);
                contentParam.setMiniprogramCardList(publishCardList);
            }

            sendIds.add(publishContent.getId());
            contentParam.setPublishContentId(publishContent.getPublishContentId());
            pushContentList.add(contentParam);
        }
        CreatePushTaskParam gzhPushParam = getCreatePushTaskParam(planAccount, pushContentList);
        if (gzhPushParam == null) {
            return;
        }
        log.info("gzhPushParam={}", gzhPushParam);
        String pushId = aigcService.createPushTask(gzhPushParam);
        log.info("pushId = {}", pushId);
        if (StringUtils.isNotEmpty(pushId)) {
            publicContentService.updatePublishContentPushId(sendIds, pushId);
        }
    }

    private List<PublishMiniprogram> getPublishMiniprogramList(List<VideoDetail> videoDetails, PlanAccount planAccount,
                                                               PublishContent publishContent) {
        if (CollectionUtils.isEmpty(videoDetails)) {
            return null;
        }
        //获取小程序卡片  判断封面是否可用
        List<PublishMiniprogram> publishMiniprogramList = cardService.generateCards(videoDetails, planAccount, publishContent);
        if (CollectionUtils.isEmpty(publishMiniprogramList)) {
            return null;
        }
//        if (!Objects.equals(publishContent.getSourceType(), SourceTypesEnum.longArticleVideoPoolSource.getVal())) {
//            if (publishMiniprogramList.size() < 2) {
//                return null;
//            }
//        }
        for (PublishMiniprogram publishMiniprogram : publishMiniprogramList) {
            //插入rootSource
            rootSourceService.addRootSource(publishMiniprogram, planAccount, publishContent);
            publishMiniprogramMapper.insertSelective(publishMiniprogram);
        }
        return publishMiniprogramList;
    }

    private CreatePushTaskParam getCreatePushTaskParam(PlanAccount planAccount, List<PushContentParam> pushContentList) {
        CreatePushTaskParam gzhPushParam = new CreatePushTaskParam();
        gzhPushParam.setPlanId(planAccount.getPlanId());
        gzhPushParam.setAccountId(planAccount.getAccountId());
        gzhPushParam.setPushType(planAccount.getPushType());
        gzhPushParam.setPushScheduleTimestamp(System.currentTimeMillis());
        if (StringUtils.isNotEmpty(planAccount.getPublishPushTime())) {
            String dateTimeStr = TimeZoneUtil.todayYMD(TimeZoneUtil.Timezone.china) + " " + planAccount.getPublishPushTime();
            gzhPushParam.setPushScheduleTimestamp(TimeZoneUtil.getDateStrTimestamp(dateTimeStr, "yyyy-MM-dd HH:mm:ss", TimeZoneUtil.Timezone.china));
        } else {
            gzhPushParam.setPushScheduleTimestamp(System.currentTimeMillis());
        }
        //文章列表为空直接返回
        if (CollectionUtils.isEmpty(pushContentList)) {
            return null;
        }
        //自动群发少于最少数量不发送
        if (Objects.equals(planAccount.getPushType(), PublishGzhPushTypeEnum.auto_group_publish.getVal())
                && pushContentList.size() < planAccount.getPublishPreMinNum()) {
            return null;
        }
        gzhPushParam.setPushContentList(pushContentList);
        return gzhPushParam;
    }

    private List<PublishMiniprogramParam> getPublishCardList(List<PublishMiniprogram> publishMiniprogramList) {
        List<PublishMiniprogramParam> publishCardList = new ArrayList<>();
        for (PublishMiniprogram publishMiniprogram : publishMiniprogramList) {
            PublishMiniprogramParam param = new PublishMiniprogramParam();
            param.setProgramId(publishMiniprogram.getAppId());
            param.setProgramName(publishMiniprogram.getAppName());
            param.setProgramAvatar(publishMiniprogram.getAvatar());
            param.setMini_id(publishMiniprogram.getMiniId());
            param.setMiniprogramUseType(publishMiniprogram.getMiniProgramType());
            String videoTitle = publishMiniprogram.getVideoTitle();
            if (org.springframework.util.StringUtils.hasText(videoTitle)) {
                videoTitle = videoTitle.replace("\"", "");
                if (videoTitle.length() > 32) {
                    videoTitle = videoTitle.substring(0, 32);
                }
                param.setProductionName(videoTitle);
            }
            param.setProductionCover(publishMiniprogram.getWxUrl());
            param.setProductionPath(publishMiniprogram.getProductionPath());
            param.setRootShareId(publishMiniprogram.getRootShareId());
            param.setSource(publishMiniprogram.getSource());
            param.setVideoUrl(publishMiniprogram.getVideoPath());
            param.setParagraphPosition(BigDecimal.valueOf(publishMiniprogram.getIndex() * 0.25));
            if (publishMiniprogram.getIndex() == 1) {
                param.setParagraphPosition(BigDecimal.valueOf(0.01));
            }
            param.setTraceId(publishMiniprogram.getTraceId());
            publishCardList.add(param);
        }
        return publishCardList;
    }

    @Override
    public void getPushStatus() {
        PublishContentExample example = new PublishContentExample();
        example.createCriteria().andStatusEqualTo(1).andPushIdIsNotNull().andCreateTimeGreaterThan(DateUtil.getThatDayDate());
        List<PublishContent> publishContents = publishContentMapper.selectByExample(example);
        Map<String, List<PublishContent>> groupedByPushId = publishContents.stream()
                .filter(content -> content.getPushId() != null) // 过滤掉 pushId 为空的情况
                .collect(Collectors.groupingBy(PublishContent::getPushId));

        for (Map.Entry<String, List<PublishContent>> entry : groupedByPushId.entrySet()) {
            String pushId = entry.getKey();
            PushStatusParam param = new PushStatusParam();
            param.setPushId(pushId);
            PushStatusVO pushStatusVO = aigcService.queryPushStatus(param);
            log.info("pushStatusVO={} param={}", pushStatusVO, param);
            if (pushStatusVO == null) {
                continue;
            }
            int updateStatus = 0;
            //推送失败
            if (pushStatusVO.getPushStatus() == 3) {
                updateStatus = 3;
            }
            //推送成功
            if (pushStatusVO.getPushStatus() == 2) {
                //发表失败
                if (pushStatusVO.getPublishStatus() == 3) {
                    updateStatus = 3;
//                    if (StringUtils.isNotEmpty(pushStatusVO.getErrorCode())) {
//                        int errorCode = Integer.parseInt(pushStatusVO.getErrorCode());
//                        if (errorCode == 6 || errorCode == 7 || errorCode == 8 || errorCode == 999) {
//                            updateStatus = 2;
//                        }
//                    }

                }
                //发表成功
                if (pushStatusVO.getPublishStatus() == 2) {
                    updateStatus = 2;
                }
            }


            Long planAccountId = entry.getValue().get(0).getPlanAccountId();
            if (planAccountId == null) {
                continue;
            }
            PlanAccount planAccount = planAccountService.getPlanAccountById(planAccountId);
            if (updateStatus == 2) {
                for (PublishContent publishContent : entry.getValue()) {
                    publicContentService.updatePublishContentStatus(updateStatus, publishContent.getId(), pushStatusVO.getErrorMsg());
                    if (Objects.equals(publishContent.getSourceType(), SourceTypesEnum.longArticleVideoPoolSource.getVal())) {
                        List<PublishMiniprogram> publishMiniprogramList = publicContentService.getPublishMiniprograms(publishContent);
                        if (CollectionUtils.isEmpty(publishMiniprogramList)) {
                            continue;
                        }
                        for (PublishMiniprogram publishMiniprogram : publishMiniprogramList) {
                            videoService.addOffVideo(publishMiniprogram);
                        }
                    }
                }
                if (planAccount == null) {
                    continue;
                }
                if (Objects.equals(planAccount.getPushType(), PublishGzhPushTypeEnum.auto_group_publish.getVal())) {
                    planAccountService.updateStatus(2, planAccountId);
                }
            }
            if (updateStatus == 3) {
                PublishContentExample publishContentExample = new PublishContentExample();
                publishContentExample.createCriteria().andPushIdEqualTo(pushId);
                PublishContent update = new PublishContent();
                if (StringUtils.isNotEmpty(pushStatusVO.getErrorMsg())) {
                    update.setReason(pushStatusVO.getErrorMsg());
                }
                update.setStatus(updateStatus);
                publishContentMapper.updateByExampleSelective(update, publishContentExample);
                if (planAccount == null) {
                    continue;
                }
                planAccountService.updateRetry(planAccount);
                if (Objects.equals(planAccount.getPushType(), PublishGzhPushTypeEnum.auto_group_publish.getVal())) {
                    if (StringUtils.isNotEmpty(pushStatusVO.getErrorMsg())) {
                        //45028群发配额用完不再重试  48004封号账号也不再重试
                        if (pushStatusVO.getErrorMsg().contains("45028") || pushStatusVO.getErrorMsg().contains("48004")) {
                            planAccountService.updateStatus(3, planAccountId);
                        }
                    }
                }
            }
            if (StringUtils.isNotEmpty(pushStatusVO.getErrorMsg()) && !pushStatusVO.getErrorMsg().contains("45028")) {
                log.error("push error pushId={} msg={}", pushId, pushStatusVO.getErrorMsg());
                String message = String.format("发布失败，请查看，pushId=%s 失败信息：%s 账号名称：%s 计划名称：%s",
                        pushId, pushStatusVO.getErrorMsg(), planAccount.getAccountName(), planAccount.getPlanName());
                LarkRobotUtil.sendMessage(message);
            }
        }
    }
}
